AJS.toInit(function() {
	var baseUrl = AJS.$("meta[name='application-base-url']").attr("content");

	// Setting the baseUrl meta tag in confluence is not working, but there is a provided
	// meta-tag called confluence-base-url that does the job.
	if(typeof baseUrl === "undefined") {
		baseUrl = AJS.$("meta[name='confluence-base-url']").attr("content");
	}

	function disableForm() {
		AJS.$(".disableable :input").prop('disabled',true);
		AJS.$("#waitmessage").show();
	}

	function enableForm() {
		AJS.$(".disableable :input").prop('disabled',false);
		AJS.$("#waitmessage").hide();
	}

	function populateForm() {
		disableForm();
		AJS.$.ajax({
			url: baseUrl + "/rest/samlsso-admin/1.0/",
			dataType: "json",
			success: function(config) {
				fillFields(config);
				
				AJS.$("#licenseMessage").text(config.licenseMessage);
				if(config.licensed) {
					AJS.$("#licenseMessage").removeClass("error");
					AJS.$("#licenseMessage").addClass("success");
				} else {
					AJS.$("#licenseMessage").addClass("error");
					AJS.$("#licenseMessage").removeClass("success");    	
				}
				enableForm();
			},
			error: function() {
				AJS.$("#aui-message-bar").empty(); 
				AJS.messages.error({
					title: "Load failed",
					body: "Loading settings failed!",
					closeable: false
				});
			}
		});
	}

	/*
	 * Writes the config into the form elements. 
	 * The value is assigned to the form element having the key as name attribute.
	 */
	function fillFields(config) {
		AJS.$.each(config, function(k,v) {
			var formElement = AJS.$("*[name=" + k + "]");
			if (formElement.length == 0) {
				console.log("Found no element with name " + k);
			} else {
				if(formElement.attr("type") == "checkbox") {
					formElement.prop('checked',v);
				} else  {
					formElement.val(v);
				}
			} 
		});
	}
	
	/*
	 * Reads the data from the form field into a JSON object.
	 * The form element's name attribute is used as key.
	 */
	function readFields() {
		var returnData = {};
		// Iterate through all input elements and textareas expect reset and submit buttons
		AJS.$("#admin").find("input:not([type='submit'],[type='reset']),textarea").each( function(index,formElement) {
			var name = AJS.$(formElement).attr("name");
			var value;
			if(AJS.$(formElement).attr("type") == "checkbox") {
				value = AJS.$(formElement).prop('checked');	// Checkboxes need to be checked for the checked attribute
			} else {
				value = AJS.$(formElement).val(); // from all other elements the value can be retrieved with the val() function 
			}
			returnData[name] = value;	
		});
		return returnData;	
	}

	function updateConfig() {
		
		disableForm();
		var ajaxdata = readFields();
		
		AJS.$.ajax({
			url: baseUrl + "/rest/samlsso-admin/1.0/",
			type: "PUT",
			contentType: "application/json; charset=utf-8",
			data: JSON.stringify(ajaxdata),
			processData: true,
			success: function () { 
				AJS.$("#aui-message-bar").empty(); 
				AJS.messages.success({
					title: "Saved",
					body: "Settings saved successfully.",
					closeable: false
				});
				populateForm();
			},
			error: function() { 
				AJS.$("#aui-message-bar").empty(); 
				AJS.messages.error({
					title: "Save failed",
					body: "Saving Settings failed!",
					closeable: false
				}); 
				populateForm();
			}
		});  
	}

	populateForm();

	AJS.$("#admin").submit(function(e) {
		e.preventDefault();
		updateConfig();
	});

	AJS.$("#cancel").click(function(e) {
		e.preventDefault();
		AJS.$("#aui-message-bar").empty(); 
		populateForm();
	});
	
}); // AJS.toInit

/*
 *  Escape newline chars for being transmitted with JSON over the wire
 */
function escapeNewLineChars(valueToEscape) {
	if (valueToEscape != null && valueToEscape != "") {
		return valueToEscape.replace(/\n/g, "\\n");
	} else {
		return valueToEscape;
	}
}
